@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: ghc-mod
 version: 5.5.0.0
-id: ghc-mod-5.5.0.0-8bc05606cb1fe18039c749e00ba585ac
-key: ghcmo_JsGifHx9AZ59Zk7WQAchaU
+id: ghc-mod-5.5.0.0-96fa5befb36696756f6fccbdb236dd5b
+key: ghcmo_EiRLRbAkA5J0g3uJG1QNhU
 license: AGPL-3
 maintainer: Daniel Gröber <dxld@darkboxed.org>
 homepage: http://www.mew.org/~kazu/proj/ghc-mod/
@@ -62,7 +62,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 data-dir: /usr/share/ghc-mod
-hs-libraries: HSghc-mod-5.5.0.0-JsGifHx9AZ59Zk7WQAchaU
+hs-libraries: HSghc-mod-5.5.0.0-EiRLRbAkA5J0g3uJG1QNhU
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -78,10 +78,10 @@ depends:
     ghc-7.10.3-523035ba1e58dc12893f7ef41f66b61d
     ghc-paths-0.1.0.9-e2ef6e39c0da729a67d19f4c6af9f657
     ghc-syb-utils-0.2.3-e762c220d86bac9001fe97a4dd0b5d58
-    haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
-    hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
+    haskell-src-exts-1.17.1-a439f7709447829586f6c45dee78a187
+    hlint-1.9.32-7fa9cde4ab28851a534bd621b44b35ee
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-journal-0.7.1-868f6722086675c90bd35d95b6eee1b6
+    monad-journal-0.7.1-3a626be79c00f2598a70f93649878d8a
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
